@@ -18,11 +18,19 @@
 #
 
 __all__ = [
-    "TR_CUT",
-    "TR_FADE",
-    "TR_FADEIO",
+    "I_CONST",
+    "I_LIN",
+    "I_SINE",
+    "I_BOUNCE",
+    "T_CUT",
+    "T_FADE",
+    "T_FADEIO",
 ]
 
-TR_CUT: int = 0
-TR_FADE: int = 1
-TR_FADEIO: int = 2
+I_CONST: int = 0
+I_LIN: int = 1
+I_SINE: int = 2
+I_BOUNCE: int = 3
+T_CUT: int = 4
+T_FADE: int = 5
+T_FADEIO: int = 6
