@@ -26,9 +26,14 @@ import os
 PARENT = os.path.dirname(os.path.realpath(__file__))
 FILE = os.path.join(PARENT, "constants.py")
 CONSTS = [
-    "TR_CUT",
-    "TR_FADE",
-    "TR_FADEIO",
+    "I_CONST",
+    "I_LIN",
+    "I_SINE",
+    "I_BOUNCE",
+
+    "T_CUT",
+    "T_FADE",
+    "T_FADEIO",
 ]
 
 
